import requests


class GitLabAPI:
    """
    A class for interacting with the GitLab API.
    """

    def __init__(self, token: str):
        """
        Initialize the GitLab API with a personal access token.

        Parameters
        ----------
        token : str
            GitLab personal access token.
        """
        self.base_url = "https://gitlab.com/api/v4"
        self.headers = {"Private-Token": token}

    def get_project_id(self, project_url: str) -> int:
        """
        Get the project ID from its URL.

        Parameters
        ----------
        project_url : str
            URL of the GitLab project.

        Returns
        -------
        int
            Project ID.
        """
        encoded_url = requests.utils.quote(project_url, safe="")
        url = f"{self.base_url}/projects/{encoded_url}"
        response = requests.get(url, headers=self.headers)
        response.raise_for_status()
        return response.json()["id"]

    def get_issues(self, project_id: int) -> list:
        """
        Retrieve issues from a GitLab project.

        Parameters
        ----------
        project_id : int
            Project ID.

        Returns
        -------
        list
            A List of issues.
        """
        url = f"{self.base_url}/projects/{project_id}/issues"
        response = requests.get(url, headers=self.headers)
        response.raise_for_status()
        return response.json()
