import requests
from task_manager import TaskManager


class DeckAPI(TaskManager):
    """
    A class for interacting with the Nextcloud Deck API.
    """

    def __init__(self, username: str, password: str, board_id: str, column_label_map: dict):
        """
        Initialize the Nextcloud Deck API.

        Parameters
        ----------
        username : str
            Nextcloud username.
        password : str
            Nextcloud password.
        board_id : str
            ID of the Deck board.
        column_label_map : dict
            Mapping of columns to their corresponding labels.
        """
        self.base_url = "https://nextcloud.example.com/apps/deck/api/v1.0"
        self.auth = (username, password)
        self.board_id = board_id
        self.column_label_map = column_label_map

    def create_task(self, title: str, description: str, labels: list):
        """
        Create a task in Deck.

        Parameters
        ----------
        title : str
            Task title.
        description : str
            Task description.
        labels : list
            A List of labels.
        """
        column_id = self._get_column_id(labels)
        if column_id is None:
            raise ValueError("No valid column found for the provided labels.")

        url = f"{self.base_url}/boards/{self.board_id}/stacks/{column_id}/cards"
        data = {"title": title, "type": "plain", "description": description}
        response = requests.post(url, auth=self.auth, json=data)
        response.raise_for_status()
        return response.json()

    def _get_column_id(self, labels: list) -> str:
        """
        Get the column ID based on labels.

        Parameters
        ----------
        labels : list
            A List of labels.

        Returns
        -------
        str
            Column ID or None if no match is found.
        """
        for column_id, column_labels in self.column_label_map.items():
            if any(label in column_labels for label in labels):
                return column_id
        return None
