from issuestoboard.config import ConfigIssuesToBoard as Config
from .gitlab_api  import GitLabAPI
from .nextcloud_api import DeckAPI
from task_manager import TaskManager


class TaskSync:
    """
    Class to synchronize GitLab issues with a task management system.
    """

    def __init__(self, gitlab_api: GitLabAPI, task_manager: TaskManager, filter_labels: list = None):
        """
        Initialize the TaskSync class.

        Parameters
        ----------
        gitlab_api : GitLabAPI
            Instance of GitLabAPI.
        task_manager : TaskManager
            Instance of a task management system.
        filter_labels : list, optional
            List of labels to filter issues.
        """
        self.gitlab_api = gitlab_api
        self.task_manager = task_manager
        self.filter_labels = set(filter_labels or [])

    def sync_project_issues(self, project_url: str):
        """
        Synchronize issues from a GitLab project.

        Parameters
        ----------
        project_url : str
            URL of the GitLab project.
        """
        project_id = self.gitlab_api.get_project_id(project_url)
        issues = self.gitlab_api.get_issues(project_id)

        for issue in issues:
            # Check if the issue has at least one allowed label
            issue_labels = set(issue.get("labels", []))
            if not self.filter_labels or self.filter_labels.intersection(issue_labels):
                self.task_manager.create_task(
                    title=issue["title"],
                    description=f"{issue['description']}\n\n[Link to GitLab Issue]({issue['web_url']})",
                    labels=list(issue_labels)
                )
                print(f"Task created for issue '{issue['title']}'")
            else:
                print(f"Issue '{issue['title']}' skipped (no matching labels).")
